Installation
============

.. contents::
    :local:

Modules
+++++++

.. autosignature:: pymyinstall.installhelper.install_cmd_helper.add_shortcut_to_desktop_for_module

.. autosignature:: pymyinstall.installhelper.install_venv_helper.create_virtual_env

.. autosignature:: pymyinstall.installhelper.module_install_version.get_module_dependencies

.. autosignature:: pymyinstall.installhelper.status_helper.get_installed_modules

.. autosignature:: pymyinstall.installhelper.module_install_version.get_module_metadata

.. autosignature:: pymyinstall.installhelper.module_install_version.get_module_version

.. autosignature:: pymyinstall.installhelper.install_cmd_helper.get_pip_program

.. autosignature:: pymyinstall.installhelper.module_install_version.get_pypi_version

.. autosignature:: pymyinstall.installhelper.module_install_version.get_wheel_version

.. autosignature:: pymyinstall.installhelper.install_cmd_helper.has_pip

.. autosignature:: pymyinstall.installhelper.module_install_version.is_installed

.. autosignature:: pymyinstall.installhelper.module_install_version.numeric_version

.. autosignature:: pymyinstall.installhelper.install_cmd_helper.run_cmd

.. autosignature:: pymyinstall.installhelper.install_venv_helper.run_cmd_path

.. autosignature:: pymyinstall.installhelper.module_dependencies.missing_dependencies

.. autosignature:: pymyinstall.installhelper.module_install.ModuleInstall

.. autosignature:: pymyinstall.installhelper.install_venv_helper.run_venv_script

.. autosignature:: pymyinstall.installhelper.install_cmd_helper.update_pip

.. autosignature:: pymyinstall.installhelper.install_venv_helper.venv_install

.. autosignature:: pymyinstall.installhelper.module_install_version.version_consensus

.. autosignature:: pymyinstall.installhelper.module_install_version.compare_version

Install
+++++++

.. autosignature:: pymyinstall.packaged.packaged_config.classifiers2string

.. autosignature:: pymyinstall.packaged.automate_install.download_module

.. autosignature:: pymyinstall.packaged.automate_install.find_module_install

.. autosignature:: pymyinstall.packaged.packaged_config.get_package_set

.. autosignature:: pymyinstall.packaged.automate_install.install_module

.. autosignature:: pymyinstall.packaged.automate_install.install_module_deps

.. autosignature:: pymyinstall.packaged.automate_install.install_all

.. autosignature:: pymyinstall.packaged.config_helper.is_64bit

.. autosignature:: pymyinstall.packaged.packaged_config.name_sets_dataframe

.. autosignature:: pymyinstall.packaged.automate_install.update_all

.. autosignature:: pymyinstall.packaged.automate_install.update_module

Tools
+++++

.. autosignature:: pymyinstall.installcustom.install_custom_7z.install_7z

.. autosignature:: pymyinstall.installcustom.install_custom_chromedriver.install_chromedriver

.. autosignature:: pymyinstall.installcustom.install_custom_git.install_git

.. autosignature:: pymyinstall.installcustom.install_custom_graphviz.install_graphviz

.. autosignature:: pymyinstall.installcustom.install_custom_inkscape.install_inkscape

.. autosignature:: pymyinstall.installcustom.install_custom_javajdk.install_javajdk

.. autosignature:: pymyinstall.installcustom.install_custom_jenkins.install_jenkins

.. autosignature:: pymyinstall.installcustom.install_custom_julia.install_julia

.. autosignature:: pymyinstall.installcustom.install_custom_miktex.install_miktex

.. autosignature:: pymyinstall.installcustom.install_custom_mingw.install_mingw

.. autosignature:: pymyinstall.installcustom.install_custom_operadriver.install_operadriver

.. autosignature:: pymyinstall.installcustom.install_custom_pandoc.install_pandoc

.. autosignature:: pymyinstall.installcustom.install_custom_putty.install_putty

.. autosignature:: pymyinstall.installcustom.install_custom_python.install_python

.. autosignature:: pymyinstall.installcustom.install_custom_R.install_R

.. autosignature:: pymyinstall.installcustom.install_custom_scite.install_scite

.. autosignature:: pymyinstall.installcustom.install_custom_sqlitespy.install_sqlitespy

.. autosignature:: pymyinstall.installcustom.install_custom_sbt.install_scala_sbt

.. autosignature:: pymyinstall.installcustom.install_custom_scite.modify_scite_properties

.. autosignature:: pymyinstall.installcustom.install_custom.where_in_path
